@@ -269,8 +269,11 @@ class ConfigurationSetupBuilder:
             self._local_settings.update(env_vars)
             
             # Also set in os.environ immediately for runtime use
+            itter = 0
             for key, value in env_vars.items():
                 os.environ[key] = value
+                print(f"{itter} Loaded for override: {key}={str(value)[:8]}...")
+                itter += 1
                 
             print(f"Applied {len(env_vars)} environment variables for {'Docker' if self._running_in_docker else 'machine'} environment")
         else:
