@@ -1,4 +1,4 @@
-from typing import Optional, Any, Dict, List, Union
+from typing import Optional, Any, Dict, List, Union, AsyncGenerator
 from contextlib import asynccontextmanager
 from azure.cosmos import CosmosClient, DatabaseProxy, ContainerProxy
 from azure.cosmos.aio import CosmosClient as AsyncCosmosClient
@@ -7,7 +7,6 @@ from azure.core.credentials import TokenCredential
 from ..mgmt.logging import AzureLogger
 from ..mgmt.identity import AzureIdentity
 
-
 class AzureCosmosDB:
     """
     Azure Cosmos DB management with standardized client initialization,
@@ -69,7 +68,7 @@ class AzureCosmosDB:
         return self.client
 
     @asynccontextmanager
-    async def async_client_context(self) -> AsyncCosmosClient:
+    async def async_client_context(self) -> AsyncGenerator[AsyncCosmosClient, None]:
         """
         Provide an asynchronous context manager for the Cosmos DB async client.
         Ensures the client is properly initialized and closed.
