@@ -297,6 +297,79 @@ class AzureStorage:
                 )
                 raise
 
+    def download_blob_by_url(
+        self,
+        blob_url: str,
+        credential: Optional[TokenCredential] = None,
+        **kwargs
+    ) -> Optional[bytes]:
+        """Download a blob directly by URL using specified credentials.
+
+        Args:
+            blob_url: Full URL to the blob (e.g., https://account.blob.core.windows.net/container/blob)
+            credential: Azure credential for authentication (if None, uses instance credential)
+            **kwargs: Additional parameters for blob download
+
+        Returns:
+            Blob data as bytes if found, None if not found
+
+        Raises:
+            ValueError: If blob URL is invalid or no credential available
+            Exception: If blob download fails for reasons other than not found
+        """
+        with self.logger.create_span(
+            "AzureStorage.download_blob_by_url",
+            attributes={
+                "service.name": self.service_name,
+                "operation.type": "blob_download_by_url",
+                "storage.blob_url": blob_url
+            }
+        ):
+            try:
+                self.logger.debug(
+                    "Downloading blob by URL",
+                    extra={"blob_url": blob_url}
+                )
+
+                # Use provided credential or fall back to instance credential
+                download_credential = credential if credential is not None else self.credential
+
+                if download_credential is None:
+                    raise ValueError("No credential available for blob download")
+
+                # Create blob client directly from URL
+                blob_client = BlobClient.from_blob_url(
+                    blob_url=blob_url,
+                    credential=download_credential
+                )
+
+                blob_data = blob_client.download_blob(**kwargs)
+                content = blob_data.readall()
+
+                self.logger.info(
+                    "Blob downloaded successfully by URL",
+                    extra={
+                        "blob_url": blob_url,
+                        "content_length": len(content) if content else 0
+                    }
+                )
+
+                return content
+
+            except ResourceNotFoundError:
+                self.logger.warning(
+                    f"Blob not found at URL: {blob_url}",
+                    extra={"blob_url": blob_url}
+                )
+                return None
+            except Exception as e:
+                self.logger.error(
+                    f"Failed to download blob by URL '{blob_url}': {e}",
+                    extra={"blob_url": blob_url},
+                    exc_info=True
+                )
+                raise
+
     def download_blob(
         self,
         container_name: str,
@@ -827,6 +900,89 @@ class AzureStorage:
             )
             raise
 
+    def get_blob_properties_by_url(
+        self,
+        blob_url: str,
+        credential: Optional[TokenCredential] = None,
+        **kwargs
+    ):
+        """Get properties of a specific blob using its URL.
+
+        Args:
+            blob_url: Full URL to the blob (e.g., https://account.blob.core.windows.net/container/blob)
+            credential: Azure credential for authentication (if None, uses instance credential)
+            **kwargs: Additional parameters for blob property retrieval
+
+        Returns:
+            Blob properties if found, None if not found
+
+        Raises:
+            ValueError: If blob URL is invalid or no credential available
+            Exception: If getting blob properties fails for reasons other than not found
+
+        Example:
+            ```python
+            storage = AzureStorage(account_url="https://account.blob.core.windows.net/")
+            url = "https://stdatarpcdev.blob.core.windows.net/documents/1-document-2025-09-18 07:40:41.333584.json"
+            properties = storage.get_blob_properties_by_url(url)
+            if properties:
+                print(f"Blob size: {properties.size}")
+                print(f"Last modified: {properties.last_modified}")
+            ```
+        """
+        with self.logger.create_span(
+            "AzureStorage.get_blob_properties_by_url",
+            attributes={
+                "service.name": self.service_name,
+                "operation.type": "blob_properties_by_url",
+                "storage.blob_url": blob_url
+            }
+        ):
+            try:
+                self.logger.debug(
+                    "Getting blob properties by URL",
+                    extra={"blob_url": blob_url}
+                )
+
+                # Use provided credential or fall back to instance credential
+                properties_credential = credential if credential is not None else self.credential
+
+                if properties_credential is None:
+                    raise ValueError("No credential available for blob properties retrieval")
+
+                # Create blob client directly from URL
+                blob_client = BlobClient.from_blob_url(
+                    blob_url=blob_url,
+                    credential=properties_credential
+                )
+
+                properties = blob_client.get_blob_properties(**kwargs)
+
+                self.logger.info(
+                    "Blob properties retrieved successfully by URL",
+                    extra={
+                        "blob_url": blob_url,
+                        "blob_size": getattr(properties, 'size', 0),
+                        "last_modified": getattr(properties, 'last_modified', None)
+                    }
+                )
+
+                return properties
+
+            except ResourceNotFoundError:
+                self.logger.warning(
+                    f"Blob not found at URL: {blob_url}",
+                    extra={"blob_url": blob_url}
+                )
+                return None
+            except Exception as e:
+                self.logger.error(
+                    f"Failed to get blob properties by URL '{blob_url}': {e}",
+                    extra={"blob_url": blob_url},
+                    exc_info=True
+                )
+                raise
+
     def upload_blob_with_sas(
         self,
         container_name: str,
