@@ -1,12 +1,16 @@
 """Azure tools package for azpaddypy.
 
 This package contains utility tools for common Azure operations
-including prompt management, data processing, and other specialized tools.
+including prompt management, configuration management, data processing, 
+and other specialized tools.
 """
 
 from .cosmos_prompt_manager import CosmosPromptManager, create_cosmos_prompt_manager
+from .configuration_manager import ConfigurationManager, create_configuration_manager
 
 __all__ = [
     "CosmosPromptManager",
     "create_cosmos_prompt_manager",
+    "ConfigurationManager", 
+    "create_configuration_manager",
 ] 
\ No newline at end of file
