@@ -2,7 +2,7 @@ import pytest
 from unittest.mock import MagicMock, patch, ANY, PropertyMock
 from azpaddypy.resources.storage import AzureStorage, create_azure_storage
 from azure.core.exceptions import ResourceNotFoundError
-from azure.storage.blob import UserDelegationKey
+from azure.storage.blob import UserDelegationKey, BlobClient
 import base64
 from datetime import timedelta
 import io
@@ -1004,4 +1004,378 @@ class TestAzureStorage:
             value = "ZmFrZV9rZXk="
         storage.user_delegation_key = FakeDelegationKey()
         result = storage.get_blob_sas("container", "blob.txt")
-        assert isinstance(result, str) and "se=" in result and "sp=" in result and "sig=" in result
\ No newline at end of file
+        assert isinstance(result, str) and "se=" in result and "sp=" in result and "sig=" in result
+
+    @patch('azure.storage.blob.BlobClient.from_blob_url')
+    def test_download_blob_by_url_success(self, mock_from_blob_url, mock_azure_identity):
+        """
+        Tests the successful download of a blob by URL using provided credentials.
+
+        This test verifies that the `download_blob_by_url` method correctly creates a
+        BlobClient from the provided URL and credential, downloads the blob content,
+        and returns the expected data.
+        """
+        mock_blob_client = MagicMock()
+        mock_download_stream = MagicMock()
+        mock_download_stream.readall.return_value = b"blob content from url"
+        mock_blob_client.download_blob.return_value = mock_download_stream
+        mock_from_blob_url.return_value = mock_blob_client
+
+        storage = AzureStorage(
+            account_url="https://testaccount.blob.core.windows.net",
+            azure_identity=mock_azure_identity
+        )
+
+        mock_custom_credential = MagicMock()
+        blob_url = "https://testaccount.blob.core.windows.net/container/test.txt"
+
+        result = storage.download_blob_by_url(
+            blob_url=blob_url,
+            credential=mock_custom_credential
+        )
+
+        assert result == b"blob content from url"
+        mock_from_blob_url.assert_called_once_with(
+            blob_url=blob_url,
+            credential=mock_custom_credential
+        )
+        mock_blob_client.download_blob.assert_called_once()
+
+    @patch('azure.storage.blob.BlobClient.from_blob_url')
+    def test_download_blob_by_url_fallback_to_instance_credential(self, mock_from_blob_url, mock_azure_identity):
+        """
+        Tests that download_blob_by_url falls back to the instance credential when no credential is provided.
+
+        This test ensures that when no credential parameter is passed, the method uses
+        the storage instance's credential for authentication.
+        """
+        mock_blob_client = MagicMock()
+        mock_download_stream = MagicMock()
+        mock_download_stream.readall.return_value = b"content with instance credential"
+        mock_blob_client.download_blob.return_value = mock_download_stream
+        mock_from_blob_url.return_value = mock_blob_client
+
+        storage = AzureStorage(
+            account_url="https://testaccount.blob.core.windows.net",
+            azure_identity=mock_azure_identity
+        )
+
+        blob_url = "https://testaccount.blob.core.windows.net/container/test.txt"
+
+        result = storage.download_blob_by_url(blob_url=blob_url)
+
+        assert result == b"content with instance credential"
+        mock_from_blob_url.assert_called_once_with(
+            blob_url=blob_url,
+            credential=storage.credential
+        )
+        mock_blob_client.download_blob.assert_called_once()
+
+    @patch('azure.storage.blob.BlobClient.from_blob_url')
+    def test_download_blob_by_url_not_found(self, mock_from_blob_url, mock_azure_identity):
+        """
+        Tests that download_blob_by_url returns None when the blob is not found.
+
+        This test verifies that when a ResourceNotFoundError is raised by the blob client,
+        the method handles it gracefully and returns None instead of propagating the exception.
+        """
+        mock_blob_client = MagicMock()
+        mock_blob_client.download_blob.side_effect = ResourceNotFoundError("Blob not found")
+        mock_from_blob_url.return_value = mock_blob_client
+
+        storage = AzureStorage(
+            account_url="https://testaccount.blob.core.windows.net",
+            azure_identity=mock_azure_identity
+        )
+
+        blob_url = "https://testaccount.blob.core.windows.net/container/nonexistent.txt"
+        mock_custom_credential = MagicMock()
+
+        result = storage.download_blob_by_url(
+            blob_url=blob_url,
+            credential=mock_custom_credential
+        )
+
+        assert result is None
+        mock_from_blob_url.assert_called_once_with(
+            blob_url=blob_url,
+            credential=mock_custom_credential
+        )
+        mock_blob_client.download_blob.assert_called_once()
+
+    def test_download_blob_by_url_no_credential_available(self, mock_azure_identity):
+        """
+        Tests that download_blob_by_url raises ValueError when no credential is available.
+
+        This test verifies that when neither a credential parameter is provided nor an
+        instance credential is available, the method raises a ValueError with an appropriate message.
+        """
+        storage = AzureStorage(
+            account_url="https://testaccount.blob.core.windows.net",
+            azure_identity=mock_azure_identity
+        )
+
+        # Remove the instance credential to simulate no credential available
+        storage.credential = None
+
+        blob_url = "https://testaccount.blob.core.windows.net/container/test.txt"
+
+        with pytest.raises(ValueError, match="No credential available for blob download"):
+            storage.download_blob_by_url(blob_url=blob_url)
+
+    @patch('azure.storage.blob.BlobClient.from_blob_url')
+    def test_download_blob_by_url_exception(self, mock_from_blob_url, mock_azure_identity):
+        """
+        Tests that download_blob_by_url properly handles and raises unexpected exceptions.
+
+        This test ensures that exceptions other than ResourceNotFoundError (such as authentication
+        errors or network issues) are properly logged and re-raised.
+        """
+        mock_blob_client = MagicMock()
+        mock_blob_client.download_blob.side_effect = Exception("Network error")
+        mock_from_blob_url.return_value = mock_blob_client
+
+        storage = AzureStorage(
+            account_url="https://testaccount.blob.core.windows.net",
+            azure_identity=mock_azure_identity
+        )
+
+        blob_url = "https://testaccount.blob.core.windows.net/container/test.txt"
+        mock_custom_credential = MagicMock()
+
+        with pytest.raises(Exception, match="Network error"):
+            storage.download_blob_by_url(
+                blob_url=blob_url,
+                credential=mock_custom_credential
+            )
+
+        mock_from_blob_url.assert_called_once_with(
+            blob_url=blob_url,
+            credential=mock_custom_credential
+        )
+        mock_blob_client.download_blob.assert_called_once()
+
+    @patch('azure.storage.blob.BlobClient.from_blob_url')
+    def test_download_blob_by_url_with_kwargs(self, mock_from_blob_url, mock_azure_identity):
+        """
+        Tests that download_blob_by_url correctly passes additional kwargs to the download_blob method.
+
+        This test verifies that any additional parameters provided via kwargs are properly
+        forwarded to the underlying download_blob call.
+        """
+        mock_blob_client = MagicMock()
+        mock_download_stream = MagicMock()
+        mock_download_stream.readall.return_value = b"content with kwargs"
+        mock_blob_client.download_blob.return_value = mock_download_stream
+        mock_from_blob_url.return_value = mock_blob_client
+
+        storage = AzureStorage(
+            account_url="https://testaccount.blob.core.windows.net",
+            azure_identity=mock_azure_identity
+        )
+
+        blob_url = "https://testaccount.blob.core.windows.net/container/test.txt"
+        mock_custom_credential = MagicMock()
+
+        result = storage.download_blob_by_url(
+            blob_url=blob_url,
+            credential=mock_custom_credential,
+            offset=100,
+            length=50
+        )
+
+        assert result == b"content with kwargs"
+        mock_from_blob_url.assert_called_once_with(
+            blob_url=blob_url,
+            credential=mock_custom_credential
+        )
+        mock_blob_client.download_blob.assert_called_once_with(offset=100, length=50)
+
+    @patch('azure.storage.blob.BlobClient.from_blob_url')
+    def test_get_blob_properties_by_url_success(self, mock_from_blob_url, mock_azure_identity):
+        """
+        Tests the successful retrieval of blob properties by URL using provided credentials.
+
+        This test verifies that the `get_blob_properties_by_url` method correctly creates a
+        BlobClient from the provided URL and credential, retrieves the blob properties,
+        and returns the expected properties object.
+        """
+        mock_blob_client = MagicMock()
+        mock_blob_properties = MagicMock()
+        mock_blob_properties.size = 1024
+        mock_blob_properties.last_modified = "2025-09-18T07:40:41Z"
+        mock_blob_client.get_blob_properties.return_value = mock_blob_properties
+        mock_from_blob_url.return_value = mock_blob_client
+
+        storage = AzureStorage(
+            account_url="https://testaccount.blob.core.windows.net",
+            azure_identity=mock_azure_identity
+        )
+
+        mock_custom_credential = MagicMock()
+        blob_url = "https://stdatarpcdev.blob.core.windows.net/documents/1-document-2025-09-18 07:40:41.333584.json"
+
+        result = storage.get_blob_properties_by_url(
+            blob_url=blob_url,
+            credential=mock_custom_credential
+        )
+
+        assert result == mock_blob_properties
+        assert result.size == 1024
+        mock_from_blob_url.assert_called_once_with(
+            blob_url=blob_url,
+            credential=mock_custom_credential
+        )
+        mock_blob_client.get_blob_properties.assert_called_once()
+
+    @patch('azure.storage.blob.BlobClient.from_blob_url')
+    def test_get_blob_properties_by_url_fallback_to_instance_credential(self, mock_from_blob_url, mock_azure_identity):
+        """
+        Tests that get_blob_properties_by_url falls back to the instance credential when no credential is provided.
+
+        This test ensures that when no credential parameter is passed, the method uses
+        the storage instance's credential for authentication.
+        """
+        mock_blob_client = MagicMock()
+        mock_blob_properties = MagicMock()
+        mock_blob_properties.content_type = "application/json"
+        mock_blob_client.get_blob_properties.return_value = mock_blob_properties
+        mock_from_blob_url.return_value = mock_blob_client
+
+        storage = AzureStorage(
+            account_url="https://testaccount.blob.core.windows.net",
+            azure_identity=mock_azure_identity
+        )
+
+        blob_url = "https://stdatarpcdev.blob.core.windows.net/documents/test-document.json"
+
+        result = storage.get_blob_properties_by_url(blob_url=blob_url)
+
+        assert result == mock_blob_properties
+        assert result.content_type == "application/json"
+        mock_from_blob_url.assert_called_once_with(
+            blob_url=blob_url,
+            credential=storage.credential
+        )
+        mock_blob_client.get_blob_properties.assert_called_once()
+
+    @patch('azure.storage.blob.BlobClient.from_blob_url')
+    def test_get_blob_properties_by_url_not_found(self, mock_from_blob_url, mock_azure_identity):
+        """
+        Tests that get_blob_properties_by_url returns None when the blob is not found.
+
+        This test verifies that when a ResourceNotFoundError is raised by the blob client,
+        the method handles it gracefully and returns None instead of propagating the exception.
+        """
+        mock_blob_client = MagicMock()
+        mock_blob_client.get_blob_properties.side_effect = ResourceNotFoundError("Blob not found")
+        mock_from_blob_url.return_value = mock_blob_client
+
+        storage = AzureStorage(
+            account_url="https://testaccount.blob.core.windows.net",
+            azure_identity=mock_azure_identity
+        )
+
+        blob_url = "https://stdatarpcdev.blob.core.windows.net/documents/nonexistent.json"
+        mock_custom_credential = MagicMock()
+
+        result = storage.get_blob_properties_by_url(
+            blob_url=blob_url,
+            credential=mock_custom_credential
+        )
+
+        assert result is None
+        mock_from_blob_url.assert_called_once_with(
+            blob_url=blob_url,
+            credential=mock_custom_credential
+        )
+        mock_blob_client.get_blob_properties.assert_called_once()
+
+    def test_get_blob_properties_by_url_no_credential_available(self, mock_azure_identity):
+        """
+        Tests that get_blob_properties_by_url raises ValueError when no credential is available.
+
+        This test verifies that when neither a credential parameter is provided nor an
+        instance credential is available, the method raises a ValueError with an appropriate message.
+        """
+        storage = AzureStorage(
+            account_url="https://testaccount.blob.core.windows.net",
+            azure_identity=mock_azure_identity
+        )
+
+        # Remove the instance credential to simulate no credential available
+        storage.credential = None
+
+        blob_url = "https://stdatarpcdev.blob.core.windows.net/documents/test.json"
+
+        with pytest.raises(ValueError, match="No credential available for blob properties retrieval"):
+            storage.get_blob_properties_by_url(blob_url=blob_url)
+
+    @patch('azure.storage.blob.BlobClient.from_blob_url')
+    def test_get_blob_properties_by_url_exception(self, mock_from_blob_url, mock_azure_identity):
+        """
+        Tests that get_blob_properties_by_url properly handles and raises unexpected exceptions.
+
+        This test ensures that exceptions other than ResourceNotFoundError (such as authentication
+        errors or network issues) are properly logged and re-raised.
+        """
+        mock_blob_client = MagicMock()
+        mock_blob_client.get_blob_properties.side_effect = Exception("Authentication error")
+        mock_from_blob_url.return_value = mock_blob_client
+
+        storage = AzureStorage(
+            account_url="https://testaccount.blob.core.windows.net",
+            azure_identity=mock_azure_identity
+        )
+
+        blob_url = "https://stdatarpcdev.blob.core.windows.net/documents/test.json"
+        mock_custom_credential = MagicMock()
+
+        with pytest.raises(Exception, match="Authentication error"):
+            storage.get_blob_properties_by_url(
+                blob_url=blob_url,
+                credential=mock_custom_credential
+            )
+
+        mock_from_blob_url.assert_called_once_with(
+            blob_url=blob_url,
+            credential=mock_custom_credential
+        )
+        mock_blob_client.get_blob_properties.assert_called_once()
+
+    @patch('azure.storage.blob.BlobClient.from_blob_url')
+    def test_get_blob_properties_by_url_with_kwargs(self, mock_from_blob_url, mock_azure_identity):
+        """
+        Tests that get_blob_properties_by_url correctly passes additional kwargs to the get_blob_properties method.
+
+        This test verifies that any additional parameters provided via kwargs are properly
+        forwarded to the underlying get_blob_properties call.
+        """
+        mock_blob_client = MagicMock()
+        mock_blob_properties = MagicMock()
+        mock_blob_properties.etag = "0x8DC123456789ABC"
+        mock_blob_client.get_blob_properties.return_value = mock_blob_properties
+        mock_from_blob_url.return_value = mock_blob_client
+
+        storage = AzureStorage(
+            account_url="https://testaccount.blob.core.windows.net",
+            azure_identity=mock_azure_identity
+        )
+
+        blob_url = "https://stdatarpcdev.blob.core.windows.net/documents/test.json"
+        mock_custom_credential = MagicMock()
+
+        result = storage.get_blob_properties_by_url(
+            blob_url=blob_url,
+            credential=mock_custom_credential,
+            timeout=30,
+            lease="lease_id"
+        )
+
+        assert result == mock_blob_properties
+        assert result.etag == "0x8DC123456789ABC"
+        mock_from_blob_url.assert_called_once_with(
+            blob_url=blob_url,
+            credential=mock_custom_credential
+        )
+        mock_blob_client.get_blob_properties.assert_called_once_with(timeout=30, lease="lease_id")
\ No newline at end of file
